local mapMod = foundation.createMod();

-- registering map files
mapMod:registerAssetId("maps/heightmap.png", "HEIGHT_MAP")
mapMod:registerAssetId("maps/material_mask.png", "MATERIAL_MASK")
mapMod:registerAssetId("maps/berries_density.png", "BERRIES_DENSITY_MAP")
mapMod:registerAssetId("maps/rock_density.png", "ROCK_DENSITY_MAP")
mapMod:registerAssetId("maps/fish_density.png", "FISH_DENSITY_MAP")
mapMod:registerAssetId("maps/tree_density_map1.png", "TREE_DENSITY_MAP1")

-- register custom map
mapMod:register({
	DataType = "CUSTOM_MAP",
	Id = "RIVERLANDS_ID",
	HeightMap = "HEIGHT_MAP",
	MaterialMask = "MATERIAL_MASK",
	MinHeight = -20,
	MaxHeight = 80,
	VillagePathList = {
		{
			Entrance = { 100, 0, 1018 },
			Exit = { 5, 0, 733 },
		},
		{
			Entrance = { 680, 0, 1018 },
			Exit = { 1020, 0, 478 },
		},
		{
			Entrance = { 5, 0, 248 },
			Exit = { 125, 0, 3 },
		}
	},
	SpawnList = {
		{
			-- creating Mineral Deposit 1
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 621 , 3 , 742 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 2
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 311 , 9 , 512 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 3
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 542 , 4 , 211 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 4
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 853 , 19 , 330 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 5
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 231 , 17 , 862 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 6
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 973 , 36 , 670 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 7
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 624 , 8 , 509 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 8
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 92 , 13 , 311 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 9
			Prefab = "PREFAB_MINERAL_SOURCE_1",
			Position = { 763 , 46 , 950 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 10
			Prefab = "PREFAB_MINERAL_SOURCE_2",
			Position = { 895 , -4 , 118 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 11
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 232 , 49 , 141 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		},
		{
			-- creating Mineral Deposit 12
			Prefab = "PREFAB_MINERAL_SOURCE_3",
			Position = { 81 , 47 , 702 },
			Orientation = { 0.0, -0.0 , 0.0},
			PatchBeforeVersion = "1.1.0"
		}
	},
	DensitySpawnList = {
			{
			-- creating Tree Density Map1
			DensityMap = "TREE_DENSITY_MAP1",
			Density = 0.8,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_TREE_PINE" },
						RandomWeight = 3.0,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.8,
							Max = 1.2
					},
						ColorRange = {
							Min = { 0.8,0.8,0.8,1 },
							Max = { 1,1,1,1 }
					}
				}
			}
		},
		{
			-- Create forest of berry bushes
			DensityMap = "BERRIES_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_BERRIES" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
			-- Create rock outcrops - stone resource
			DensityMap = "ROCK_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_ROCK" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		},
		{
			-- Create fish shoals
			DensityMap = "FISH_DENSITY_MAP",
			Density =0.9,
			PrefabConfigList = {
				{
						PrefabList = { "PREFAB_RESOURCE_FISH" },
						RandomWeight = 0.1,
						OffsetSizeRange = {
							Min = 0.75,
							Max = 1.0
					},
						OrientationRange = {
							Min = { 0, -180, 0 },
							Max = { 0, 180, 0 }
					},
						ScaleRange = {
							Min = 0.85,
							Max = 1.15
					},
						ColorRange = {
							Min = { 0.8, 0.8, 0.8, 1 },
							Max = { 1, 1, 1, 1 }
					}
				}
			}
		}
	}
})
-- This map was created with the help of the UFME
